<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="117"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="127"/>
        <source>Show/hide main menu</source>
        <translation>アプリケーションメニューの表示/非表示</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="530"/>
        <source>Add to desktop</source>
        <translation>デスクトップに追加する</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="538"/>
        <source>Question</source>
        <translation>質問</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="539"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>同じ名前のファイルが既に存在します。
上書きしますか？</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="545"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="546"/>
        <source>The file cannot be overwritten.</source>
        <translation>ファイルを上書き出来ません。</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="552"/>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>全般</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu Settings</source>
        <translation>アプリケーションメニューの設定</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>アイコン:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>ボタンの文字列:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>フォントサイズの指定:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> ポイント</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>メニューファイル</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>メニューファイル:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>アイテムの表示最大幅:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>一致するエントリ名を表示する:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>アイテムの表示最大数:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>メニューエントリを絞り込む</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>検索中はメニューエントリを隠す</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>メニューを表示した時、検索フォームをクリアする</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>ショートカットキー</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>ショートカットを記録するには次のボタンをクリック:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>アイコンファイルの選択</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>画像 (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>メニューファイルの選択</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>メニューファイル (*.menu)</translation>
    </message>
</context>
</TS>
